==> aws-cdk.aws-stepfunctions-1.88.0.tar.gz: package/lib/stepfunctions-canned-metrics.generated.d.ts <==
export declare class StatesMetrics {
    static executionTimeAverage(dimensions: {
        StateMachineArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            StateMachineArn: string;
        };
        statistic: string;
    };
    static executionsFailedAverage(dimensions: {
        StateMachineArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            StateMachineArn: string;
        };
        statistic: string;
    };
    static executionsSucceededAverage(dimensions: {
        StateMachineArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            StateMachineArn: string;
        };
        statistic: string;
    };
    static executionsThrottledAverage(dimensions: {
        StateMachineArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            StateMachineArn: string;
        };
        statistic: string;
    };
    static executionsAbortedAverage(dimensions: {
        StateMachineArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            StateMachineArn: string;
        };
        statistic: string;
    };
    static executionsTimedOutAverage(dimensions: {
        StateMachineArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            StateMachineArn: string;
        };
        statistic: string;
    };
    static activityTimeAverage(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activitiesSucceededSum(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activitiesFailedSum(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activitiesHeartbeatTimedOutSum(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activitiesScheduledSum(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activitiesStartedSum(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activitiesTimedOutSum(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activityRunTimeAverage(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activityScheduleTimeAverage(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensions: {
            ActivityArn: string;
        };
        statistic: string;
    };
}

==> aws-cdk.aws-stepfunctions-1.137.0.tar.gz: package/lib/stepfunctions-canned-metrics.generated.d.ts <==
export declare class StatesMetrics {
    static executionTimeAverage(dimensions: {
        StateMachineArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            StateMachineArn: string;
        };
        statistic: string;
    };
    static executionsFailedAverage(dimensions: {
        StateMachineArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            StateMachineArn: string;
        };
        statistic: string;
    };
    static executionsSucceededAverage(dimensions: {
        StateMachineArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            StateMachineArn: string;
        };
        statistic: string;
    };
    static executionsThrottledAverage(dimensions: {
        StateMachineArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            StateMachineArn: string;
        };
        statistic: string;
    };
    static executionsAbortedAverage(dimensions: {
        StateMachineArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            StateMachineArn: string;
        };
        statistic: string;
    };
    static executionsTimedOutAverage(dimensions: {
        StateMachineArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            StateMachineArn: string;
        };
        statistic: string;
    };
    static activityTimeAverage(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activitiesSucceededSum(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activitiesFailedSum(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activitiesHeartbeatTimedOutSum(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activitiesScheduledSum(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activitiesStartedSum(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activitiesTimedOutSum(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activityRunTimeAverage(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ActivityArn: string;
        };
        statistic: string;
    };
    static activityScheduleTimeAverage(dimensions: {
        ActivityArn: string;
    }): {
        namespace: string;
        metricName: string;
        dimensionsMap: {
            ActivityArn: string;
        };
        statistic: string;
    };
}
